@@ -11,8 +11,7 @@ from google.oauth2.service_account import Credentials
 DEFAULT_LOG_FILE_NAME = "coco-agent"
 DEFAULT_CLOUD_LOGGING_HANDLER_NAME = "coco-agent"
 LOG_FORMAT = (
-    # TODO: revert pathname to filename once done with noisy cloud logging output diagnosis
-    "%(asctime)s.%(msecs)03d %(pathname)s:%(lineno)d %(levelname)s: %(message)s"
+    "%(asctime)s.%(msecs)03d %(filename)s:%(lineno)d %(levelname)s: %(message)s"
 )
 LOG_DATE_FORMAT = "%Y-%m-%d %H:%M:%S"
 
@@ -100,4 +99,4 @@ def apply_log_config(
     logging.basicConfig(format=LOG_FORMAT, datefmt=LOG_DATE_FORMAT)
 
     # remove noise
-    logging.getLogger("google.cloud.logging").setLevel(logging.ERROR)
+    logging.getLogger("google.cloud").setLevel(logging.ERROR)
